package com.zanxiang.sdk.controller;

import com.zanxiang.common.domain.ResultVO;
import com.zanxiang.sdk.common.annotation.ValidLogin;
import com.zanxiang.sdk.domain.params.*;
import com.zanxiang.sdk.domain.vo.UserLoginVO;
import com.zanxiang.sdk.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author : lingfeng
 * @time : 2022-06-16
 * @description : 用户接口
 */
@Api(tags = "用户接口")
@RestController
@RequestMapping(value = "/api/user")
public class UserController {

    @Autowired
    private UserService userService;

    @Autowired
    private UserOauthService userOauthService;

    @Autowired
    private GameUserRoleService gameUserRoleService;

    @Autowired
    private GameUserService gameUserService;

    @Autowired
    private UserTokenService userTokenService;

    @ApiOperation(value = "登录凭证验证")
    @GetMapping("/token/check")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Long.class)})
    public ResultVO userTokenCheck(@RequestParam Long gameId, @RequestParam Long userId,
                                   @RequestParam String token, @RequestParam String sign) {
        return userTokenService.userTokenCheck(gameId, userId, token, sign);
    }

    @ApiOperation(value = "用户重置密码")
    @PostMapping("/update/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO updatePassword(@Validated @RequestBody UpdatePasswordParam updatePasswordParam, UserData userData) {
        return userService.updatePassword(updatePasswordParam, userData);
    }

    @ApiOperation(value = "用户获取信息详情")
    @PostMapping("/get/user/detail")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO getUserDetail(@Validated @RequestBody UserDetailParam userDetailParam, UserData userData) {
        return userService.getUserDetail(userDetailParam, userData);
    }

    @ApiOperation(value = "更新用户授权信息")
    @PostMapping("/update/user/Oauth")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO updateUserOauth(@Validated @RequestBody UserOauthlUpdateParam param, @ValidLogin UserData userData) {
        return userOauthService.updateUserOauth(param, userData);
    }

    @ApiOperation(value = "创建/更新游戏用户")
    @PostMapping("/update/game/user")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO updateGameUser(@Validated @RequestBody GameUserUpdateParam param, @ValidLogin UserData userData) {
        return ResultVO.ok(gameUserService.updateGameUser(param, userData));
    }

    @ApiOperation(value = "上传角色信息")
    @PostMapping("/update/game/role")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO updateUserGameRole(@Validated @RequestBody GameUserRoleUpdateParam param, @ValidLogin UserData userData) {
        return ResultVO.ok(gameUserRoleService.updateUserGameRole(param, userData));
    }

    @ApiOperation(value = "用户信息检测")
    @PostMapping("/check")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO upUserGameRole(@Validated @RequestBody UserCheckParam param, @ValidLogin UserData userData) {
        return ResultVO.ok(userService.userCheck(param, userData));
    }

}
